summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/managedconnectionaccount.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:51 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-18 18:33:51 -0600
commit089118c18533dfa3e6ce5065dbebdd4db94051f1 (patch)
treece014fb2326a80fcfafa2362b7ff88486aa17c96 /kopete/libkopete/managedconnectionaccount.h
parent83677e35509b4dafac63b76995652bdf3b49f209 (diff)
downloadtdenetwork-089118c18533dfa3e6ce5065dbebdd4db94051f1.tar.gz
tdenetwork-089118c18533dfa3e6ce5065dbebdd4db94051f1.zip
Rename old tq methods that no longer need a unique name
Diffstat (limited to 'kopete/libkopete/managedconnectionaccount.h')
-rw-r--r--kopete/libkopete/managedconnectionaccount.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kopete/libkopete/managedconnectionaccount.h b/kopete/libkopete/managedconnectionaccount.h
index a27bd7cd..755fbf71 100644
--- a/kopete/libkopete/managedconnectionaccount.h
+++ b/kopete/libkopete/managedconnectionaccount.h
@@ -27,7 +27,7 @@ namespace Kopete
class Protocol;
/**
* A ManagedConnectionAccount queries the NetworktqStatus KDED Module before trying to connect using
* connectwithPassword, starting a network connection if needed. If the network is not available,
* it delays calling performConnectWithPassword until it receives notification from the daemon
* that the network is up. The account receiveds notifications from the daemon of network failures
@@ -69,7 +69,7 @@ class KOPETE_EXPORT ManagedConnectionAccount : public PasswordedAccount
* @param host For future expansion.
* @param status the new status of the network
*/
- virtual void slotConnectionStatusChanged( const TQString & host, NetworktqStatus::EnumtqStatus status );
+ virtual void slotConnectionStatusChanged( const TQString & host, NetworkStatus::EnumStatus status );
private:
TQString m_password;
bool m_waitingForConnection;
@@ -27,7 +27,7 @@ namespace Kopete
class Protocol;
/**
- * A ManagedConnectionAccount queries the NetworktqStatus KDED Module before trying to connect using
+ * A ManagedConnectionAccount queries the NetworkStatus KDED Module before trying to connect using
* connectwithPassword, starting a network connection if needed. If the network is not available,
* it delays calling performConnectWithPassword until it receives notification from the daemon